==> jc-1.4.0.tar.gz: soot/javaToJimple/PrivateFieldAccMethodSource.h <==
// public class soot.javaToJimple.PrivateFieldAccMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4eed156df5440ef soot_javaToJimple_PrivateFieldAccMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_
#define _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_FieldInstance$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$object;

typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$setFieldInst$d7c8e7ca2cafca05(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method_info$getBody$01a871f1d690f082;
extern _jc_method _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method_info$setFieldInst$d7c8e7ca2cafca05;

// Virtual methods structure
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
	void	(*setFieldInst$d7c8e7ca2cafca05)(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods	soot_javaToJimple_PrivateFieldAccMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs {
	struct _jc_object	*fieldInst;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs {
    _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs	soot_javaToJimple_PrivateFieldAccMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs	soot_javaToJimple_PrivateFieldAccMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object {
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype _jc_soot_javaToJimple_PrivateFieldAccMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_PrivateFieldAccMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_PrivateFieldAccMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/PrivateFieldAccMethodSource.h <==
// public class soot.javaToJimple.PrivateFieldAccMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4eed156df5440ef soot_javaToJimple_PrivateFieldAccMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_
#define _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_FieldInstance$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$object;

typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method$setFieldInst$d7c8e7ca2cafca05(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method_info$getBody$01a871f1d690f082;
extern _jc_method _jc_soot_javaToJimple_PrivateFieldAccMethodSource$method_info$setFieldInst$d7c8e7ca2cafca05;

// Virtual methods structure
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setFieldInst$d7c8e7ca2cafca05)(_jc_env *, struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vmethods	soot_javaToJimple_PrivateFieldAccMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs {
	struct _jc_object	*fieldInst;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs {
    _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_refs	soot_javaToJimple_PrivateFieldAccMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_PrivateFieldAccMethodSource$sub_nonrefs	soot_javaToJimple_PrivateFieldAccMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_PrivateFieldAccMethodSource$object {
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_PrivateFieldAccMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_PrivateFieldAccMethodSource$vtype _jc_soot_javaToJimple_PrivateFieldAccMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_PrivateFieldAccMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_PrivateFieldAccMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_PrivateFieldAccMethodSource_H_ */
